@@ -12,7 +12,7 @@ from tiddlyweb.util import sha
 from tiddlywebplugins.utils import get_store
 
 
-__version__ = '0.9.4'
+__version__ = '0.9.6'
 
 
 ANY_NAMESPACE = 'any_namespace'
@@ -26,7 +26,7 @@ def container_namespace_key(container, container_name=''):
         key = '%s_namespace' % container
     else:
         key = '%s:%s_namespace' % (container, container_name)
-    return key.encode('UTF-8', 'replace')
+    return sha(key.encode('UTF-8', 'replace')).hexdigest()
 
 
 def tiddler_change_hook(store, tiddler):
@@ -276,7 +276,6 @@ class Store(StorageInterface):
         return sha(fullkey.encode('UTF-8')).hexdigest()
 
     def _get(self, key):
-        logging.warn('trying cache key %s', key)
         return self._mc.get(key)
 
 
